#' ---
#' title: Example report including repeated subreports on subsamples of the data
#' author: Gilles San Martin
#' date: "`r Sys.setlocale('LC_ALL', 'en_GB.UTF-8'); format(Sys.time(), '%d %B %Y')`"
#' ---

# /* 
# ---------------- This part is just for report production -------------------
# */

#+ echo = FALSE, warning = FALSE, error = FALSE, message = FALSE
# source("/home/gilles/stats/makereport.R")
# makereport("subreport_parent.R", output = c("html"),  wd= "/home/gilles/stats/Formation_R_stats/Formation_stats/Formation_Stats_1_R/Exemples_rapports")

library(knitr)
opts_chunk$set(dev = c("png", "cairo_pdf"), fig.width = 10/2.54, fig.height= 10/2.54, 
               echo=FALSE, results= "markup", warning = FALSE, 
               error = FALSE, message = FALSE, cache = FALSE, tidy = FALSE, 
               tidy.opts=list(width.cutoff=95))

library(pander)
panderOptions("table.style" , "rmarkdown")
panderOptions("table.split.table" , Inf)
panderOptions("table.alignment.rownames" , "right")

options(width = 110)

# setwd("/home/gilles/stats/Exemple_code/knitr/")

#'
#'  
#' *********************************************************************************
#'
#' \newpage
#' 



# /* 
# ---------------- Import Data -------------------
# */

#' # Aim
#' 
#' Short toy example to show hot to build a parent report with subreports (child reports) repeated on 
#' subsamples of the data within a loop.
#' We first describe the Iris dataset. Then for each of the 4 variables measured we perform
#' the same analysis and plots repeated. these analyses are performed in a `subreport_child.Rmd`
#' file on the disc, compiled by the `knitr` function `knit_child()` and then inserted in 
#' the parent report/document. Then we continue with a few analyses/info on the main parent
#' report (scatterplot matrix, Info Session).
#' 

#' # Data used
#' 
#' Dataset for 3 _Iris_ species (_Iris virginica_, _Iris setosa_, _Iris versicolor_) with
#' 4 morphological variables measured : 
#' 
#' * Sepal length
#' * Sepal width
#' * Petal length
#' * Petal width
#' 

data(iris)
d <- iris

#' **Random sample :**
pander(d[sample(1:nrow(d), 5),])

#' **Summary :**
pander(summary(d))


#' **Structure :**  
str(d)

#'
#' \pagebreak
#' 

vars <- colnames(d)[1:4]


#' # Description of each variable
#' 

#+ echo = FALSE, results = "hide"
# Here we compile each subreport template with knit_child that returns the results as 
# markdown. Then the result is displayed in the next chunk with result = "asis" option
res <- NULL
for (i in 1:4) {
    var <- d[,i]
    varname <- colnames(d)[i]
    res <- c(res, knit_child(text = knit_expand("subreport_child.Rmd")))
}


#+ results = "asis"
cat (res)


#' # Scatterplots matrix
#' 

#+ fig.width = 18/2.54, fig.height = 14/2.54
# dev.new(width = 18/2.54, height = 14/2.54)
pairs(d, gap = 0, col = d[,5])



#' \pagebreak
#' 
#' # Session Info
#' 
sessionInfo()




